package com.sun.jmx.snmp;

import java.net.UnknownHostException;
import java.net.InetAddress;

public class SnmpString extends SnmpValue
{
    private static final long serialVersionUID = -7011986973225194188L;
    static final String name = "String";
    protected byte[] value;
    
    public SnmpString() {
        this.value = null;
        this.value = new byte[0];
    }
    
    public SnmpString(byte[] array) {
        this.value = null;
        this.value = (byte[])array.clone();
    }
    
    public SnmpString(Byte[] array) {
        this.value = null;
        this.value = new byte[array.length];
        for (int i = 0; i < array.length; ++i) {
            this.value[i] = (byte)array[i];
        }
    }
    
    public SnmpString(String s) {
        this.value = null;
        this.value = s.getBytes();
    }
    
    public SnmpString(InetAddress inetAddress) {
        this.value = null;
        this.value = inetAddress.getAddress();
    }
    
    public InetAddress inetAddressValue() throws UnknownHostException {
        return InetAddress.getByAddress(this.value);
    }
    
    public static String BinToChar(String s) {
        char[] value = new char[s.length() / 8];
        for (int length = value.length, i = 0; i < length; ++i) {
            value[i] = (char)Integer.parseInt(s.substring(8 * i, 8 * i + 8), 2);
        }
        return new String(value);
    }
    
    public static String HexToChar(String s) {
        char[] value = new char[s.length() / 2];
        for (int length = value.length, i = 0; i < length; ++i) {
            value[i] = (char)Integer.parseInt(s.substring(2 * i, 2 * i + 2), 16);
        }
        return new String(value);
    }
    
    public byte[] byteValue() {
        return (byte[])this.value.clone();
    }
    
    public Byte[] toByte() {
        Byte[] array = new Byte[this.value.length];
        for (int i = 0; i < this.value.length; ++i) {
            array[i] = new Byte(this.value[i]);
        }
        return array;
    }
    
    @Override
    public String toString() {
        return new String(this.value);
    }
    
    @Override
    public SnmpOid toOid() {
        long[] array = new long[this.value.length];
        for (int i = 0; i < this.value.length; ++i) {
            array[i] = (long)(this.value[i] & 0xFF);
        }
        return new SnmpOid(array);
    }
    
    public static SnmpOid toOid(long[] array, int n) throws SnmpStatusException {
        try {
            if (array[n] > 2147483647L) {
                throw new SnmpStatusException(2);
            }
            int n2 = (int)array[n++];
            long[] array2 = new long[n2];
            for (int i = 0; i < n2; ++i) {
                array2[i] = array[n + i];
            }
            return new SnmpOid(array2);
        }
        catch (IndexOutOfBoundsException ex) {
            throw new SnmpStatusException(2);
        }
    }
    
    public static int nextOid(long[] array, int n) throws SnmpStatusException {
        try {
            if (array[n] > 2147483647L) {
                throw new SnmpStatusException(2);
            }
            n += (int)array[n++];
            if (n <= array.length) {
                return n;
            }
            throw new SnmpStatusException(2);
        }
        catch (IndexOutOfBoundsException ex) {
            throw new SnmpStatusException(2);
        }
    }
    
    public static void appendToOid(SnmpOid snmpOid, SnmpOid snmpOid2) {
        snmpOid2.append((long)snmpOid.getLength());
        snmpOid2.append(snmpOid);
    }
    
    @Override
    public final synchronized SnmpValue duplicate() {
        return (SnmpValue)this.clone();
    }
    
    public synchronized Object clone() {
        SnmpString snmpString;
        try {
            snmpString = (SnmpString)super.clone();
            snmpString.value = new byte[this.value.length];
            System.arraycopy(this.value, 0, snmpString.value, 0, this.value.length);
        }
        catch (CloneNotSupportedException cause) {
            throw new InternalError(cause);
        }
        return snmpString;
    }
    
    @Override
    public String getTypeName() {
        return "String";
    }
}
